==> lifetype-1.1.tbz: www/lifetype/class/database/pdb/datadict/pdbmysqldatadict.class.php <==
<?php
    
    /**
      V4.62 2 Apr 2005  (c) 2000-2005 John Lim (jlim@natsoft.com.my). All rights reserved.
      Released under both BSD license and Lesser GPL library license. 
      Whenever there is any discrepancy between the two licenses, 
      the BSD license will take precedence.
    */
    
    include_once( PLOG_CLASS_PATH."class/database/pdb/datadict/pdbbasedatadict.class.php" );
    
    /**
     * Data dictionary for MySQL, used by PDb to be able to convert a table meta-definition
 	 * into SQL executable code for altering the db schema, adding new fields, etc.
     *
     * \ingroup PDb
     */    
    class PDbMysqlDataDict extends PDbBaseDataDict 
	{
        var $databaseType = 'mysql';
        var $alterCol = ' MODIFY COLUMN';
        var $alterTableAddIndex = true;
        var $dropTable = 'DROP TABLE IF EXISTS %s'; // requires mysql 3.22 or later
        
        var $dropIndex = 'DROP INDEX %s ON %s';
        var $renameColumn = 'ALTER TABLE %s CHANGE COLUMN %s %s %s';	// needs column-definition!

        /**
		 * @see PdbBaseDataDict::MetaType
		 */
        function MetaType($t,$len=-1,$fieldobj=false)
        {
            if (is_object($t)) {
                $fieldobj = $t;
                $t = $fieldobj->type;
                $len = $fieldobj->max_length;
            }
            $is_serial = is_object($fieldobj) && $fieldobj->primary_key && $fieldobj->auto_increment;
            
            $len = -1; // mysql max_length is not accurate
            switch (strtoupper($t)) {
            case 'STRING': 
            case 'CHAR':
            case 'VARCHAR': 
            case 'TINYBLOB': 
            case 'TINYTEXT': 
            case 'ENUM': 
            case 'SET':
                if ($len <= $this->blobSize) return 'C';
                
            case 'TEXT':
            case 'LONGTEXT': 
            case 'MEDIUMTEXT':
                return 'X';
                
            // php_mysql extension always returns 'blob' even if 'text'
            // so we have to check whether binary...
            case 'IMAGE':
            case 'LONGBLOB': 
            case 'BLOB':
            case 'MEDIUMBLOB':
                return !empty($fieldobj->binary) ? 'B' : 'X';
                
            case 'YEAR':
            case 'DATE': return 'D';
            
            case 'TIME':
            case 'DATETIME':
            case 'TIMESTAMP': return 'T';
            
            case 'FLOAT':
            case 'DOUBLE':
                return 'F';
                
            case 'INT': 
            case 'INTEGER': return $is_serial ? 'R' : 'I';
            case 'TINYINT': return $is_serial ? 'R' : 'I1';
            case 'SMALLINT': return $is_serial ? 'R' : 'I2';
            case 'MEDIUMINT': return $is_serial ? 'R' : 'I4';
            case 'BIGINT':  return $is_serial ? 'R' : 'I8';
            default: return 'N';
            }
        }
    
        /**
		 * @see PdbBaseDataDict::ActualType
		 */
        function ActualType($meta)
        {
            switch(strtoupper($meta)) {
            case 'C': return 'VARCHAR';
            case 'XL':return 'LONGTEXT';
            case 'X': return 'TEXT';
            
            case 'C2': return 'VARCHAR';
            case 'X2': return 'LONGTEXT';
            
            case 'B': return 'LONGBLOB';
                
            case 'D': return 'DATE';
            case 'T': return 'TIMESTAMP';
            case 'L': return 'TINYINT';
            
            case 'R':
            case 'I4':
            case 'I': return 'INTEGER';
            case 'I1': return 'TINYINT';
            case 'I2': return 'SMALLINT';
            case 'I8': return 'BIGINT';
            
            case 'F': return 'FLOAT';
            case 'N': return 'NUMERIC';
            default:
                return $meta;
            }
        }
        
		/**
		 * @private
		 */
        function _CreateSuffix($fname,$ftype,$fnotnull,$fdefault,$fautoinc,$fconstraint,$funsigned)
        {	
            $suffix = '';
            if ($funsigned) $suffix .= ' UNSIGNED';
            if ($fnotnull) $suffix .= ' NOT NULL';
            if (strlen($fdefault)) $suffix .= " DEFAULT $fdefault";
            if ($fautoinc) $suffix .= ' AUTO_INCREMENT';
            if ($fconstraint) $suffix .= ' '.$fconstraint;
            return $suffix;
        }        
        
		/**
		 * @private
		 */
        function _IndexSQL($idxname, $tabname, $flds, $idxoptions)
        {
            $sql = array();
            
            if ( isset($idxoptions['REPLACE']) || isset($idxoptions['DROP']) ) {
                if ($this->alterTableAddIndex) $sql[] = "ALTER TABLE $tabname DROP INDEX $idxname";
                else $sql[] = sprintf($this->dropIndex, $idxname, $tabname);
    
                if ( isset($idxoptions['DROP']) )
                    return $sql;
            }
            
            if ( empty ($flds) ) {
                return $sql;
            }
            
            if (isset($idxoptions['FULLTEXT'])) {
                $unique = ' FULLTEXT';
            } elseif (isset($idxoptions['UNIQUE'])) {
                $unique = ' UNIQUE';
            } else {
                $unique = '';
            }
            
            if ( is_array($flds) ) $flds = implode(', ',$flds);
            
            if ($this->alterTableAddIndex) $s = "ALTER TABLE $tabname ADD $unique INDEX $idxname ";
            else $s = 'CREATE' . $unique . ' INDEX ' . $idxname . ' ON ' . $tabname;
            
            $s .= ' (' . $flds . ')';
            
            if ( isset($idxoptions[$this->upperName]) )
                $s .= $idxoptions[$this->upperName];
            
            $sql[] = $s;
            
            return $sql;
        }
    }
?>

==> lifetype-1.2.11.tbz: www/lifetype/class/database/pdb/datadict/pdbmysqldatadict.class.php <==
<?php
    
    /**
      V4.62 2 Apr 2005  (c) 2000-2005 John Lim (jlim@natsoft.com.my). All rights reserved.
      Released under both BSD license and Lesser GPL library license. 
      Whenever there is any discrepancy between the two licenses, 
      the BSD license will take precedence.
    */
    
    lt_include( PLOG_CLASS_PATH."class/database/pdb/datadict/pdbbasedatadict.class.php" );
    
    /**
     * Data dictionary for MySQL, used by PDb to be able to convert a table meta-definition
 	 * into SQL executable code for altering the db schema, adding new fields, etc.
     *
     * \ingroup PDb
     */    
    class PDbMysqlDataDict extends PDbBaseDataDict 
	{
        var $databaseType = 'mysql';
        var $alterCol = ' MODIFY COLUMN';
        var $alterTableAddIndex = true;
        var $dropTable = 'DROP TABLE IF EXISTS %s'; // requires mysql 3.22 or later
        
        var $dropIndex = 'DROP INDEX %s ON %s';
        var $renameColumn = 'ALTER TABLE %s CHANGE COLUMN %s %s %s';	// needs column-definition!

        /**
		 * @see PdbBaseDataDict::MetaType
		 */
        function MetaType($t,$len=-1,$fieldobj=false)
        {
            if (is_object($t)) {
                $fieldobj = $t;
                $t = $fieldobj->type;
                $len = $fieldobj->max_length;
            }
            $is_serial = is_object($fieldobj) && $fieldobj->primary_key && $fieldobj->auto_increment;
            
            $len = -1; // mysql max_length is not accurate
            switch (strtoupper($t)) {
            case 'STRING': 
            case 'CHAR':
            case 'VARCHAR': 
            case 'TINYBLOB': 
            case 'TINYTEXT': 
            case 'ENUM': 
            case 'SET':
                if ($len <= $this->blobSize) return 'C';
                
            case 'TEXT':
            case 'LONGTEXT': 
            case 'MEDIUMTEXT':
                return 'X';
                
            // php_mysql extension always returns 'blob' even if 'text'
            // so we have to check whether binary...
            case 'IMAGE':
            case 'LONGBLOB': 
            case 'BLOB':
            case 'MEDIUMBLOB':
                return !empty($fieldobj->binary) ? 'B' : 'X';
                
            case 'YEAR':
            case 'DATE': return 'D';
            
            case 'TIME':
            case 'DATETIME':
            case 'TIMESTAMP': return 'T';
            
            case 'FLOAT':
            case 'DOUBLE':
                return 'F';
                
            case 'INT': 
            case 'INTEGER': return $is_serial ? 'R' : 'I';
            case 'TINYINT': return $is_serial ? 'R' : 'I1';
            case 'SMALLINT': return $is_serial ? 'R' : 'I2';
            case 'MEDIUMINT': return $is_serial ? 'R' : 'I4';
            case 'BIGINT':  return $is_serial ? 'R' : 'I8';
            default: return 'N';
            }
        }
    
        /**
		 * @see PdbBaseDataDict::ActualType
		 */
        function ActualType($meta)
        {
            switch(strtoupper($meta)) {
            case 'C': return 'VARCHAR';
            case 'XL':return 'LONGTEXT';
            case 'X': return 'TEXT';
            
            case 'C2': return 'VARCHAR';
            case 'X2': return 'LONGTEXT';
            
            case 'B': return 'LONGBLOB';
                
            case 'D': return 'DATE';
            case 'T': return 'TIMESTAMP';
            case 'L': return 'TINYINT';
            
            case 'R':
            case 'I4':
            case 'I': return 'INTEGER';
            case 'I1': return 'TINYINT';
            case 'I2': return 'SMALLINT';
            case 'I8': return 'BIGINT';
            
            case 'F': return 'FLOAT';
            case 'N': return 'NUMERIC';
            default:
                return $meta;
            }
        }
        
		/**
		 * @private
		 */
        function _CreateSuffix($fname,$ftype,$fnotnull,$fdefault,$fautoinc,$fconstraint,$funsigned)
        {	
            $suffix = '';
            if ($funsigned) $suffix .= ' UNSIGNED';
            if ($fnotnull) $suffix .= ' NOT NULL';
            if (strlen($fdefault)) $suffix .= " DEFAULT $fdefault";
            if ($fautoinc) $suffix .= ' AUTO_INCREMENT';
            if ($fconstraint) $suffix .= ' '.$fconstraint;
            return $suffix;
        }        
        
		/**
		 * @private
		 */
        function _IndexSQL($idxname, $tabname, $flds, $idxoptions)
        {
            $sql = array();
            
            if ( isset($idxoptions['REPLACE']) || isset($idxoptions['DROP']) ) {
                if ($this->alterTableAddIndex) $sql[] = "ALTER TABLE $tabname DROP INDEX $idxname";
                else $sql[] = sprintf($this->dropIndex, $idxname, $tabname);
    
                if ( isset($idxoptions['DROP']) )
                    return $sql;
            }
            
            if ( empty ($flds) ) {
                return $sql;
            }
            
            if (isset($idxoptions['FULLTEXT'])) {
                $unique = ' FULLTEXT';
            } elseif (isset($idxoptions['UNIQUE'])) {
                $unique = ' UNIQUE';
            } else {
                $unique = '';
            }
            
            if ( is_array($flds) ) $flds = implode(', ',$flds);
            
            if ($this->alterTableAddIndex) $s = "ALTER TABLE $tabname ADD $unique INDEX $idxname ";
            else $s = 'CREATE' . $unique . ' INDEX ' . $idxname . ' ON ' . $tabname;
            
            $s .= ' (' . $flds . ')';
            
            if ( isset($idxoptions[$this->upperName]) )
                $s .= $idxoptions[$this->upperName];
            
            $sql[] = $s;
            
            return $sql;
        }
    }
?>
